@@ -31,9 +31,10 @@
 #include <stdarg.h>
 #include <errno.h>
 #include <netdb.h>
+#include <netinet/in.h>
 
-#include "ukcprog.h"
-#include "statgrab.h"
+#include <ukcprog.h>
+#include <statgrab.h>
 
 #define LOG_CRIT 0
 #define LOG_ERR 1
@@ -46,6 +47,8 @@ typedef struct{
 
 	char *host_ip;
 	char *host_fqdn;
+	int preset_fqdn;
+	int preset_ip;
 
 	char *server_fqdn;
 	int server_udp_port;
@@ -405,14 +408,25 @@ int ihost_getconfig(ihost_state_t *ihost_state){
 	 * this already be NULL */
         if(ihost_state->file_list!=NULL) free(ihost_state->file_list);
         if(ihost_state->last_modified!=NULL) free(ihost_state->last_modified);
-        if(ihost_state->host_fqdn!=NULL) free(ihost_state->host_fqdn);
         if(ihost_state->server_fqdn!=NULL) free(ihost_state->server_fqdn);
-	if(ihost_state->host_ip!=NULL) free(ihost_state->host_ip);
+
+	if(ihost_state->preset_fqdn){
+		if(host_fqdn != NULL) free(host_fqdn);
+	}else{
+        	if(ihost_state->host_fqdn!=NULL) free(ihost_state->host_fqdn);
+		ihost_state->host_fqdn=host_fqdn;
+	}
+
+	if(ihost_state->preset_ip){
+		if(host_ip != NULL) free(host_ip);
+	}else{
+		if(ihost_state->host_ip!=NULL) free(ihost_state->host_ip);
+		ihost_state->host_ip=host_ip;
+	}
+
 
 	ihost_state->file_list=file_list;
 	ihost_state->last_modified=last_modified;
-	ihost_state->host_fqdn=host_fqdn;
-	ihost_state->host_ip=host_ip;
 	ihost_state->server_fqdn=server_fqdn;
 	ihost_state->server_udp_port=server_udp_port;
 	ihost_state->udp_update_time=udp_update_time;
@@ -702,6 +716,8 @@ void usage(char *progname){
         fprintf(stderr, "Options\n");
         fprintf(stderr, "  -v           Verbose mode,-vv would make even more verbose\n");
         fprintf(stderr, "  -f           Foreground mode, print errors to stderr\n");
+	fprintf(stderr, "  -s		Set the machine name to be reported as\n");
+	fprintf(stderr, "  -i		Set the IP to be reported as\n");
         fprintf(stderr, "  -V           Print version number\n");
         fprintf(stderr, "  -h           Prints this help page\n");
         exit(1);
@@ -733,11 +749,13 @@ int main(int argc, char **argv){
 	ihost_state.filtermanager_host=NULL;
 	ihost_state.host_fqdn=NULL;
 	ihost_state.host_ip=NULL;
+	ihost_state.preset_fqdn = 0;
+	ihost_state.preset_ip = 0;
 	ihost_state.server_fqdn=NULL;
 	ihost_state.file_list=NULL;
 	ihost_state.last_modified=NULL;
 
-        while((cmdopt=getopt(argc, argv, "vfhV")) != -1){
+        while((cmdopt=getopt(argc, argv, "vfhVs:i:")) != -1){
                 switch(cmdopt){
                         case 'v':
                                 ihost_config.verbose++;
@@ -755,6 +773,23 @@ int main(int argc, char **argv){
                         case 'V':
                                 fprintf(stderr, "%s version %s\n", argv[0], VERSION);
                                 break;
+			case 's':
+				ihost_state.preset_fqdn = 1;
+				ihost_state.host_fqdn = strdup(optarg);
+				if(ihost_state.host_fqdn == NULL){
+					fprintf(stderr, "Missing hostname\n");	
+					usage(argv[0]);
+				}
+				break;
+			case 'i':
+				/* Hmm.. Someone could set any string to be the IP, and it will let it */
+				ihost_state.preset_ip = 1;
+				ihost_state.host_ip = strdup(optarg);
+				if(ihost_state.host_ip == NULL){
+					fprintf(stderr, "Missing ip\n");	
+					usage(argv[0]);
+				}
+				break;
 
                         default:
                                 usage(argv[0]);
